﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Reflection;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.Graphics.Printing;
using Windows.Storage;
using Windows.Storage.Pickers;
using Windows.UI.Popups;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;
using Windows.UI.Xaml.Printing;
using Syncfusion.UI.Xaml.RichTextBoxAdv;
using System.ComponentModel;
using System.Text;
namespace RTESample
{
    public partial class MainPage : Page
    {
        #region Field
        private bool skipUpdatingView = false;
        #endregion

        #region Constructor
        /// <summary>
        /// Initializes a new instance of the <see cref="MainPage"/> class.
        /// </summary>
        public MainPage()
        {
            InitializeComponent();
            DataContext = new ViewModel();
            richTextBoxAdv.ContentChanged += RichTextBoxAdv_ContentChanged;
            (DataContext as ViewModel).PropertyChanged += viewModel_PropertyChanged;
        }
        #endregion

        #region Events
        /// <summary>
        /// Handles the PropertyChanged event of the viewModel control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="PropertyChangedEventArgs"/> instance containing the event data.</param>
        void viewModel_PropertyChanged(object sender, PropertyChangedEventArgs e)
        {
            if (skipUpdatingView)
            {
                skipUpdatingView = false;
                return;
            }
            // Updates the contents SfRichTextBoxAdv control on RTFString value changed.
            Stream stream = new MemoryStream();
            byte[] rtfBytes = Encoding.GetEncoding("ASCII").GetBytes((sender as ViewModel).RtfString);
            stream.Write(rtfBytes, 0, rtfBytes.Length);
            stream.Position = 0;
            richTextBoxAdv.Load(stream, FormatType.Rtf);
        }
        /// <summary>
        /// Handles the ContentChanged event of the RichTextBoxAdv control.
        /// </summary>
        /// <param name="obj">The source of the event.</param>
        /// <param name="args">The <see cref="ContentChangedEventArgs"/> instance containing the event data.</param>
        void RichTextBoxAdv_ContentChanged(object obj, ContentChangedEventArgs args)
        {
            Stream stream = new MemoryStream();
            richTextBoxAdv.Save(stream, FormatType.Rtf);
            stream.Position = 0;
            byte[] rtfBytes = new byte[stream.Length];
            stream.Read(rtfBytes,0,(int)stream.Length);
            string rtf = Encoding.GetEncoding("ASCII").GetString(rtfBytes,0,rtfBytes.Length).ToLower();
            if ((this.DataContext as ViewModel).RtfString != rtf)
            {
                //Updates the changes made in SfRichTextBoxAdv to ViewModel.
                //RTF string of SfRichTextBoxAdv Document, is updated only on accessing this property. Hence it gets the RTF string based on current content and update to ViewModel.
                skipUpdatingView = true;
                (this.DataContext as ViewModel).RtfString = rtf;
            }
        }
        /// <summary>
        /// Handles the Click event of the LoadRTF control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="RoutedEventArgs"/> instance containing the event data.</param>
        private void LoadRTF_Click(object sender, RoutedEventArgs e)
        {
            Assembly assembly = typeof(MainPage).GetTypeInfo().Assembly;
            Stream stream = assembly.GetManifestResourceStream("RTESample.Assets.GettingStarted.rtf");
            byte[] rtfBytes = new byte[stream.Length];
            stream.Read(rtfBytes,0,rtfBytes.Length);
            // Sets the rtf string to View model RTFString.
            (this.DataContext as ViewModel).RtfString = Encoding.GetEncoding("ASCII").GetString(rtfBytes, 0, rtfBytes.Length);
        }
        #endregion
    }
    /// <summary>
    /// Sample View Model class
    /// </summary>
    public class ViewModel : INotifyPropertyChanged
    {
        #region Field
        private String rtfString;
        #endregion

        #region Constructor
        /// <summary>
        /// Initializes a new instance of the <see cref="ViewModel"/> class.
        /// </summary>
        public ViewModel()
        {
        }
        #endregion

        #region Properties
        /// <summary>
        /// Gets or sets the RTF string.
        /// </summary>
        /// <value>
        /// The RTF string.
        /// </value>
        public String RtfString
        {
            get
            {
                return rtfString;
            }
            set
            {
                rtfString = value;
                if (PropertyChanged != null)
                    PropertyChanged(this, new PropertyChangedEventArgs("RtfString"));
            }
        }
        #endregion

        #region Event
        public event PropertyChangedEventHandler PropertyChanged;
        #endregion
    }
}
